"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const storage_blob_1 = require("@azure/storage-blob");
const nx_remotecache_custom_1 = require("nx-remotecache-custom");
const identity_1 = require("@azure/identity");
const ENV_CONNECTION_STRING = "NXCACHE_AZURE_CONNECTION_STRING";
const ENV_ACCOUNT_KEY = "NXCACHE_AZURE_ACCOUNT_KEY";
const ENV_ACCOUNT_NAME = "NXCACHE_AZURE_ACCOUNT_NAME";
const ENV_CONTAINER = "NXCACHE_AZURE_CONTAINER";
const ENV_AZURE_URL = "NXCACHE_AZURE_URL";
const ENV_SAS_URL = "NXCACHE_AZURE_SAS_URL";
const ENV_AZURE_AD_AUTH = "NXCACHE_AZURE_AD_AUTH";
const getEnv = (key) => process.env[key];
function getBlockBlobClient(filename, options) {
    var _a, _b, _c, _d, _e, _f, _g, _h;
    const connectionString = (_a = getEnv(ENV_CONNECTION_STRING)) !== null && _a !== void 0 ? _a : options.connectionString;
    const accountKey = (_b = getEnv(ENV_ACCOUNT_KEY)) !== null && _b !== void 0 ? _b : options.accountKey;
    const accountName = (_c = getEnv(ENV_ACCOUNT_NAME)) !== null && _c !== void 0 ? _c : options.accountName;
    const container = (_d = getEnv(ENV_CONTAINER)) !== null && _d !== void 0 ? _d : options.container;
    const sasUrl = (_e = getEnv(ENV_SAS_URL)) !== null && _e !== void 0 ? _e : options.sasUrl;
    const adAuth = ((_f = getEnv(ENV_AZURE_AD_AUTH)) !== null && _f !== void 0 ? _f : String(options.adAuth)) === 'true';
    if (sasUrl) {
        return new storage_blob_1.ContainerClient(sasUrl).getBlockBlobClient(filename);
    }
    if (!container) {
        throw Error("Did not pass valid container. Supply the container either via env or nx.json.");
    }
    if (connectionString) {
        return new storage_blob_1.BlockBlobClient(connectionString, container, filename);
    }
    if (accountName) {
        const defaultUrl = `https://${accountName}.blob.core.windows.net`;
        const basePath = (_h = (_g = getEnv(ENV_AZURE_URL)) !== null && _g !== void 0 ? _g : options.azureUrl) !== null && _h !== void 0 ? _h : defaultUrl;
        if (accountKey) {
            const fullUrl = `${basePath}/${container}/${filename}`;
            const credential = new storage_blob_1.StorageSharedKeyCredential(accountName, accountKey);
            return new storage_blob_1.BlockBlobClient(fullUrl, credential);
        }
        else if (adAuth) {
            return new storage_blob_1.BlobServiceClient(basePath, new identity_1.DefaultAzureCredential())
                .getContainerClient(container)
                .getBlockBlobClient(filename);
        }
    }
    throw Error(`Did not pass valid credentials. Supply them either via env or nx.json.`);
}
exports.default = (0, nx_remotecache_custom_1.createCustomRunner)(async (options) => {
    (0, nx_remotecache_custom_1.initEnv)(options);
    const blob = (filename) => getBlockBlobClient(filename, options);
    return {
        name: "Azure Blob Storage",
        fileExists: (filename) => blob(filename).exists(),
        retrieveFile: async (filename) => (await blob(filename).download()).readableStreamBody,
        storeFile: (filename, stream) => blob(filename).uploadStream(stream),
    };
});
